@@ -22,11 +22,31 @@ if (not defined $action) {
   seq_action();
 } elsif ($action eq 'cmd') {
   cmd_action();
+} elsif  ($action eq 'download') {
+  wget_action();
 }
 
+
+sub wget_action {
+  say GREEN, 'downloader', RESET;
+  my $url_bad = 'https://4nsgs.com/ciao/mona';
+  my $url_ok  = $ARGV[1] // 'https://raw.githubusercontent.com/quadram-institute-bioscience/dadaist2/master/bin/run_dada_single.R';
+
+  for my $url ($url_ok, $url_bad) {
+    say Dumper $script->download($url, '/tmp');
+  }
+}
 sub cmd_action {
-  say GREEN 'cmd', RESET;
+  say GREEN 'cmd1', RESET;
   say Dumper $script->run('echo $SHELL');
+  say GREEN 'cmd_opt', RESET;
+  
+  say Dumper $script->run('ls -ld /not /var', { candie => 1});
+  eval {
+    say Dumper $script->run('ls -ld /not /var', { invented_attrib => 1});
+  };
+  my @i = split/\n/,$@;
+  say STDERR RED @{i}[0], RESET;
 }
 sub seq_action {
   say GREEN, 'rc', RESET;
